@@ -1,7 +1,7 @@
 # reportbug_submit module - email and GnuPG functions
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2006 Chris Lawrence
-#   Copyright (C) 2008-2015 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2016 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -34,7 +34,7 @@ from email.MIMEAudio import MIMEAudio
 from email.MIMEImage import MIMEImage
 from email.MIMEBase import MIMEBase
 from email.MIMEMessage import MIMEMessage
-from email.Header import Header
+from email.Header import Header, decode_header
 import mimetypes
 
 from __init__ import VERSION, VERSION_NUMBER
@@ -44,6 +44,7 @@ from exceptions import (
 )
 import ui.text_ui as ui
 from utils import get_email_addr
+import errno
 
 quietly = False
 
@@ -95,6 +96,12 @@ def rfc2047_encode_header(header, charset, mua=None):
     return encode_if_needed(header, charset)
 
 
+def decode_email_header(header):
+    # returns a list of 2-items tuples
+    decoded = decode_header(header)
+    return ' '.join([x[0] for x in decoded]).strip()
+
+
 # Cheat for now.
 # ewrite() may put stuff on the status bar or in message boxes depending on UI
 def ewrite(*args):
@@ -311,7 +318,13 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
     message = message.as_string()
     if paranoid and not (template or printonly):
         pager = os.environ.get('PAGER', 'sensible-pager')
-        os.popen(pager, 'w').write(message)
+        try:
+            os.popen(pager, 'w').write(message)
+        except  Exception, e:
+            # if the PAGER exits before all the text has been sent,
+            # it'd send a SIGPIPE, so crash only if that's not the case
+            if e.errno != errno.EPIPE:
+                raise e
         if not ui.yes_no('Does your report seem satisfactory', 'Yes, send it.',
                          'No, don\'t send it.'):
             smtphost = mta = None
@@ -363,9 +376,14 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
             mta, commands.mkarg(envfrom), jalist), 'w')
         using_sendmail = True
 
+    # saving a backup of the report
+    backupfh, backupname = TempFile(prefix=tempfile_prefix(package, 'backup'), dir=draftpath)
+    ewrite('Saving a backup of the report at %s\n', backupname)
+    backupfh.write(message)
+    backupfh.close()
+
     if smtphost:
         toaddrs = [x[1] for x in alist]
-        smtp_message = re.sub(r'(?m)^[.]', '..', message)
 
         tryagain = True
         refused = None
@@ -395,7 +413,7 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                             'Enter SMTP password for %s@%s: ' %
                             (smtpuser, smtphost))
                     conn.login(smtpuser, smtppasswd)
-                refused = conn.sendmail(fromaddr, toaddrs, smtp_message)
+                refused = conn.sendmail(fromaddr, toaddrs, message)
                 conn.quit()
             except (socket.error, smtplib.SMTPException), x:
                 # If wrong password, try again...
@@ -488,14 +506,14 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
         if len(addresses):
             ewrite("Copies sent to:\n")
             for address in addrs:
-                ewrite('  %s\n', address)
+                ewrite('  %s\n', decode_email_header(address))
 
         if debbugs_cc and rtype == 'debbugs':
             ewrite("Copies will be sent after processing to:\n")
             for address in cclist:
-                ewrite('  %s\n', address)
+                ewrite('  %s\n', decode_email_header(address))
 
-    if not (exinfo or kudos) and rtype == 'debbugs' and sysinfo and not failed \
+    if not (exinfo or kudos) and rtype == 'debbugs' and sysinfo and 'email' in sysinfo and not failed \
             and mailing:
         ewrite('\n')
         ui.final_message(
