@@ -30,7 +30,7 @@ except ImportError:
 global vte
 
 try:
-    import gtkspell
+    import gtkspellcheck
     has_spell = True
 except:
     has_spell = False
@@ -907,7 +907,11 @@ class HandleBTSQueryPage(TreePage):
             (count, sectitle, hierarchy) = debbugs.get_reports(
                 package, timeout, bts, mirrors=mirrors, version=version,
                 http_proxy=http_proxy, archived=archived, source=source)
+        except:
+            error_dialog("Unable to connect to %s BTS." % sysinfo['name'])
+            raise NoBugs
 
+        try:
             if not count:
                 if hierarchy is None:
                     raise NoPackage
@@ -931,8 +935,6 @@ class HandleBTSQueryPage(TreePage):
 
                 return(report, sectitle), {}
 
-        except(IOError, NoNetwork):
-            error_dialog("Unable to connect to %s BTS." % sysinfo['name'])
         except NoPackage:
             error_dialog('No record of this package found.')
             raise NoPackage
@@ -1145,7 +1147,7 @@ class EditorPage(Page):
         self.view.modify_font(pango.FontDescription("Monospace"))
         self.view.set_wrap_mode(gtk.WRAP_WORD)
         if has_spell:
-            gtkspell.Spell(self.view)
+            gtkspellcheck.SpellChecker(self.view)
         self.info_buffer = self.view.get_buffer()
         scrolled = create_scrollable(self.view)
         vbox.pack_start(scrolled)
@@ -1160,7 +1162,7 @@ class EditorPage(Page):
 
         if not has_spell:
             box = gtk.EventBox()
-            label = gtk.Label("Please install <b>python-gtkspell</b> to enable spell checking")
+            label = gtk.Label("Please install <b>python-gtkspellcheck</b> to enable spell checking")
             label.set_use_markup(True)
             label.set_line_wrap(True)
             label.set_selectable(True)
