@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2015 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2016 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -52,6 +52,8 @@ STATUSDB = os.path.join(DPKGLIB, 'status')
 PSEUDOHEADERS = ('Package', 'Source', 'Version', 'Severity', 'File', 'Tags',
                  'Justification', 'Followup-For', 'Owner', 'User', 'Usertags',
                  'Forwarded', 'Control')
+# These pseudo-headers can be repeated in the report
+REPEATABLE_PSEUDOHEADERS = ['Control',]
 
 MODES = {'novice': 'Offer simple prompts, bypassing technical questions.',
          'standard': 'Offer more extensive prompts, including asking about '
@@ -89,12 +91,15 @@ NEWBIELINE = """Dear Maintainer,
 fhs_directories = ['/', '/usr', '/usr/share', '/var', '/usr/X11R6',
                    '/usr/man', '/usr/doc', '/usr/bin']
 
-# A map between suites and distributions names
-SUITES2DISTS = {'squeeze': 'oldstable',
-                'wheezy': 'stable',
-                'jessie': 'testing',
+# A map between codenames and suites
+CODENAME2SUITE = {'squeeze': 'oldoldstable',
+                'wheezy': 'oldstable',
+                'jessie': 'stable',
+                'stretch': 'testing',
+                'buster': 'next-testing',
                 'sid': 'unstable',
                 'experimental': 'experimental'}
+SUITE2CODENAME = dict([(suite, codename) for codename, suite in CODENAME2SUITE.items()])
 
 
 def realpath(filename):
@@ -1165,6 +1170,7 @@ def cleanup_msg(dmessage, headers, pseudos, type):
                 ph += [header]
     else:
         ph2 = {}
+        repeatable_ph = []
         # generate a list of pseudoheaders, but without duplicates
         # we take the list of pseudoheaders defined in reportbug and add
         # the ones passed by the user (if not already present). We are not using
@@ -1177,13 +1183,17 @@ def cleanup_msg(dmessage, headers, pseudos, type):
         for header, content in pseudoheaders:
             # if either in the canonical pseudo-headers list or in those passed on the command line
             if header in pseudo_list:
-                ph2[header] = content
+                if header not in REPEATABLE_PSEUDOHEADERS:
+                    ph2[header] = content
+                else:
+                    repeatable_ph += ['%s: %s' % (header, content)]
             else:
                 newheaders.append((header, content))
 
         for header in pseudo_list:
             if header in ph2:
                 ph += ['%s: %s' % (header, ph2[header])]
+        ph.extend(repeatable_ph)
 
     return message, newheaders, ph
 
